remove

Function remove 

pub fn remove<'s>(s: &'s str, k: &str) -> (String, Option<&'s str>)
Remove every entry for a &str-key from s preserving the insertion order of the remaining entries. Returns the value of the first removed entry, if any.