Timestamp

Struct Timestamp 

pub struct Timestamp { /* private fields */ }
A timestamp made of a NTP64 and a crate::HLC’s unique identifier.

Conversion to/from String

A Timestamp is formatted to a String as such: "<ntp64_time>/<hlc_id_hexadecimal>" 2 different String representations are supported:

  1. <ntp64_time> as an unsigned integer in decimal format
  1. <ntp64_time>as a RFC3339 (human readable) format:
  • Such conversion loses some precision because of rounding when conferting the fraction part to nanoseconds
  • As a consequence it’s not bijective: a Timestamp converted to RFC3339 String and then converted back to Timestamp might result to a different time.
  • Timestamp to String: use std::fmt::Display::fmt() with the alternate flag ({:#}) or Timestamp::to_string_rfc3339_lossy().
  • String to Timestamp: use Timestamp::parse_rfc3339()

Implementations

Source

impl Timestamp

pub fn new(time: NTP64, id: ID) -> Timestamp

pub fn get_time(&self) -> &NTP64

pub fn get_id(&self) -> &ID

pub fn get_diff_duration(&self, other: &Timestamp) -> Duration

pub fn to_string_rfc3339_lossy(&self) -> String

Convert to a RFC3339 time representation with nanoseconds precision. e.g.: `“2024-07-01T13:51:12.129693000Z/33”``

pub fn parse_rfc3339(s: &str) -> Result<Timestamp, ParseTimestampError>

Parse a RFC3339 time representation into a NTP64.