Request

Struct Request 

pub struct Request {
    pub id: RequestId,
    pub wire_expr: WireExpr<'static>,
    pub ext_qos: QoSType,
    pub ext_tstamp: Option<TimestampType>,
    pub ext_nodeid: NodeIdType,
    pub ext_target: QueryTarget,
    pub ext_budget: Option<BudgetType>,
    pub ext_timeout: Option<TimeoutType>,
    pub ext_ts_stack: Option<TsStackType>,
    pub payload: RequestBody,
}
Request message

Flags:
- N: Named          if N==1 then the key expr has name/suffix
- M: Mapping        if M==1 then key expr mapping is the one declared by the sender, else it is the one declared by the receiver
- Z: Extension      if Z==1 then at least one extension is present

 7 6 5 4 3 2 1 0
+-+-+-+-+-+-+-+-+
|Z|M|N| Request |
+-+-+-+---------+
~ request_id:z32~  (*)
+---------------+
~ key_scope:z16 ~
+---------------+
~  key_suffix   ~  if N==1 -- <u8;z16>
+---------------+
~   [req_exts]  ~  if Z==1
+---------------+
~  RequestBody  ~  -- Payload
+---------------+

(*) The resolution of the request id is negotiated during the session establishment.
    This implementation limits the resolution to 32bit.

Fields

id: RequestIdwire_expr: WireExpr<'static>ext_qos: QoSTypeext_tstamp: Option<TimestampType>ext_nodeid: NodeIdTypeext_target: QueryTargetext_budget: Option<BudgetType>ext_timeout: Option<TimeoutType>ext_ts_stack: Option<TsStackType>payload: RequestBody

Implementations