Module timestamp_stack

Module timestamp_stack 

Modules

interception_point
Bitmask flags indicating which interception points are activated in a timestamp stack.

Structs

Interception
A single interception record containing the interception point identifier, timestamp format flag, and raw timestamp bytes.
TimestampStack
A stack of interception timestamps carried as a message extension.
TsStackType
Zenoh extension wrapper for the timestamp stack.

Constants

MAX_STACK_SIZE