pub struct TimestampStack {
pub conf_flags: u8,
pub stack: Vec<Interception>,
}Expand description
A stack of interception timestamps carried as a message extension.
Flags:
- S: Send If S==1 then the send interception point is activated.
- R: Route If R==1 then the route interception point is activated.
- E: Receive If E==1 then the receive interception point is activated.
- X: Reserved
7 6 5 4 3 2 1 0
+-+-+-+-+-+-+-+-+
|X|X|X|X|X|E|R|S|
+---------------+
~ count: zint ~
+---------------+
~ [Interception] ~
+---------------+Fields
conf_flags: u8Bitmask of which interception points are activated.
stack: Vec<Interception>Ordered list of interceptions collected along the message path.