Parameters

Struct Parameters 

pub struct Parameters<'s>(/* private fields */);
A map of key/value (String, Vec<String>) parameters.

It can be parsed from a String, using ; as separator between each parameter and = as separator between a key and its value.

Keys can have multiple values, using | as a separator between them. An iterator for these can be obtained with Parameters::values.

Example:

use zenoh_protocol::core::Parameters;

let a = "a=1;b=2;c=3|4|5;d=6";
let p = Parameters::from(a);

// Retrieve values
assert!(!p.is_empty());
assert_eq!(p.get("a").unwrap(), "1");
assert_eq!(p.get("b").unwrap(), "2");
assert_eq!(p.get("c").unwrap(), "3|4|5");
assert_eq!(p.get("d").unwrap(), "6");
assert_eq!(p.values("c").collect::<Vec<&str>>(), vec!["3", "4", "5"]);

// Iterate over parameters
let mut iter = p.iter();
assert_eq!(iter.next().unwrap(), ("a", "1"));
assert_eq!(iter.next().unwrap(), ("b", "2"));
assert_eq!(iter.next().unwrap(), ("c", "3|4|5"));
assert_eq!(iter.next().unwrap(), ("d", "6"));
assert!(iter.next().is_none());

// Create parameters from iterators
let pi = Parameters::from_iter(vec![("a", "1"), ("b", "2"), ("c", "3|4|5"), ("d", "6")]);
assert_eq!(p, pi);

Implementations

Source

impl<'s> Parameters<'s>

pub const fn empty() -> Self

Create empty parameters.

pub fn is_empty(&self) -> bool

Returns true if parameters does not contain anything.

pub fn as_str(&'s self) -> &'s str

Returns parameters as str.

pub fn contains_key<K>(&self, k: K) -> bool
where K: Borrow<str>,

Returns true if parameters contains the specified key.

pub fn get<K>(&'s self, k: K) -> Option<&'s str>
where K: Borrow<str>,

Returns a reference to the &str-value corresponding to the key.

pub fn values<K>(&'s self, k: K) -> impl DoubleEndedIterator<Item = &'s str>
where K: Borrow<str>,

Returns an iterator to the &str-values corresponding to the key.

pub fn iter( &'s self, ) -> impl DoubleEndedIterator<Item = (&'s str, &'s str)> + Clone

Returns an iterator on the key-value pairs as (&str, &str).

pub fn insert<K, V>(&mut self, k: K, v: V) -> Option<String>
where K: Borrow<str>, V: Borrow<str>,

Inserts a key-value pair into the map. If the map did not have this key present, None is returned. If the map did have this key present, the value is updated, and the old value is returned.

pub fn remove<K>(&mut self, k: K) -> Option<String>
where K: Borrow<str>,

Removes a key from the map, returning the value at the key if the key was previously in the parameters.

pub fn extend(&mut self, other: &Parameters<'_>)

Extend these parameters with other parameters.

pub fn extend_from_iter<'e, I, K, V>(&mut self, iter: I)
where I: Iterator<Item = (&'e K, &'e V)> + Clone, K: Borrow<str> + 'e + ?Sized, V: Borrow<str> + 'e + ?Sized,

Extend these parameters from an iterator.

pub fn into_owned(self) -> Parameters<'static>

Convert these parameters into owned parameters.

pub fn is_ordered(&self) -> bool

Returns true if all keys are sorted in alphabetical order.