Bitmask flags indicating which interception points are activated in a timestamp stack.
Constants
- IS_
CUSTOM_ TS - Bit 7 of the
Interception.flagsfield: set when the timestamp was produced by a user-defined callback (custom format), cleared when it is a standard UHLC timestamp. - RECEIVE
- ROUTE
- SEND